/**
 * Copyright  World Wide Web Consortium, (Massachusetts Institute of
 * Technology, Institut National de Recherche en Informatique et en
 * Automatique, Keio University).
 *
 * All Rights Reserved.
 *
 * @author	Sergey Melnik <melnik@db.stanford.edu>
 */
package org.w3c.rdf.model.impl;

import org.w3c.rdf.model.RDFNode;
import org.w3c.tools.crypt.*;

public abstract class RDFNodeImpl implements RDFNode, Digestable {

  protected String label;
  protected Digest digest;

  protected RDFNodeImpl() {
  }

  public RDFNodeImpl(String label) {
    this.label = label;
  }

  public String	toString () {
    return label;
  }

  public String	getLabel () {
    return label;
  }

  public int hashCode() {

    return DigestUtil.getHashCode(getDigest());
  }

  // implementation of Digestable

  public Digest getDigest() {

    if(digest == null) {
      digest = new Md5Digest(label, "UTF8");
    }
    return digest;
  }

  public boolean equals (Object that) {

    if(that instanceof Digestable) {
      return DigestUtil.equal(getDigest(), ((Digestable)that).getDigest());
    }

    return label.equals( ((RDFNode)that).getLabel() );
  }
}
